# -*- coding: utf-8 -*-

from plbrdidge.core.config import conf, speedup
from plbrdidge.core.multithreading import Multithreading
from plbrdidge.utils.dataframe_utils import DataFrameUtils
from plbrdidge.utils.duration import Duration
from plbrdidge.utils.logger import logger
from plbrdidge.utils.udf_utils import UdfUtils


class Node:
    def __init__(self, upstream_node=None, output_table=None):
        self.input_table = None
        self.output_table = output_table
        self.permanent_table = None
        self.upstream_check(upstream_node)
        self.additional_input()
        self.dfu = DataFrameUtils() if conf['df'] is None else conf['df']
        self.udfu = UdfUtils() if conf['udf'] is None else conf['udf']
        self.mt = Multithreading()

    def upstream_check(self, upstream_node):
        if upstream_node is None:
            return
        if self.dfu.exist_table(upstream_node.output_table):
            logger.info(
                f"SUCCESS|{upstream_node.__class__.__name__}:{upstream_node.output_table}=>{self.__class__.__name__}")
        else:
            logger.info(
                f"FAILURE|{upstream_node.__class__.__name__}:{upstream_node.output_table}=>{self.__class__.__name__}")
            # upstream_node.execute()
        self.input_table = upstream_node.output_table

    def additional_input(self):
        pass

    def execute(self):
        duration = Duration()
        logger.info(f'START:{self.__class__.__name__}:in={self.input_table},out={self.output_table}')
        self.preprocess_duration()
        self.run_duration()
        self.postprocess_duration()
        logger.info(f'END:{self.__class__.__name__}:{duration.minute()},in={self.input_table},out={self.output_table}')

    def preprocess_duration(self):
        duration = Duration()
        self.preprocess()
        logger.info(f'{self.__class__.__name__}:preprocess:{duration.minute()}')

    def run_duration(self):
        duration = Duration()
        self.run()
        logger.info(f'{self.__class__.__name__}:run:{duration.minute()}')

    def postprocess_duration(self):
        duration = Duration()
        self.postprocess()
        logger.info(f'{self.__class__.__name__}:postprocess:{duration.minute()}')

    def preprocess(self):
        pass

    def run(self):
        pass

    def postprocess(self):
        pass

    def _permanent(self, partitions=['dc']):
        self.mt.init(input_tables=[self.output_table], prefix=speedup['partition'])
        df = self.dfu.get_table(self.output_table)
        self.mt.async_df(df, out_table=self.permanent_table, partition_list=partitions, drop=False)
