# -*- coding: utf-8 -*-
from odps import ODPS, DataFrame

from plbrdidge.core.config import conf
from plbrdidge.core.config import odps_conf as oc
from plbrdidge.utils.logger import logger


class DataFrameUtils():
    def __init__(self):
        logger.info(f'odps_conf:projects:{oc["projects"]},default={conf["project"]}')
        self.clients = {}
        if oc['access_id'] is None or oc['access_key'] is None:
            logger.info((f"DataFrame:AuthenticationError:access_id={oc['access_id']},access_key={oc['access_key']}"))
        for proj in oc['projects']:
            self.clients[proj] = ODPS(oc['access_id'], oc['access_key'], proj, oc['endpoint'])
        self.default_client = self.clients[conf['project']]

    def _client(self, proj=None):
        if proj is None:
            return self.default_client
        return self.default_client if self.clients[proj] is None else self.clients[proj]

    def exist_table(self, table):
        pt = table.split(".")
        proj, table_name = pt[0], pt[1]
        o = self._client(proj)
        return o.exist_table(table_name, project=proj)

    def delete_table(self, table, if_exists=True):
        pt = table.split(".")
        proj, table_name = pt[0], pt[1]
        o = self._client(proj)
        return o.delete_table(table_name, project=proj, if_exists=if_exists)

    def create_table(self, table, schema, if_not_exists=True, lifecycle=7):
        pt = table.split(".")
        proj, table_name = pt[0], pt[1]
        o = self._client(proj)
        return o.create_table(table, schema, project=proj, if_not_exists=if_not_exists, lifecycle=lifecycle)

    def write_table(self, table, df, partitions=None, create_partition=True):
        pt = table.split(".")
        proj, table_name = pt[0], pt[1]
        o = self._client(proj)
        return o.write_table(table, df, partitions=partitions, create_partition=create_partition)

    def get_table(self, table):
        pt = table.split(".")
        proj, table_name = pt[0], pt[1]
        o = self._client(proj)
        return DataFrame(o.get_table(table_name, project=proj))
