# -*- coding: utf-8 -*-
from io import StringIO

import bytedtos

from plbrdidge.core.config import tos_conf as conf
from plbrdidge.utils.duration import Duration
from plbrdidge.utils.logger import logger


class TosUtils():
    def __init__(self):
        logger.info(f'conf:{conf}')
        self.client = bytedtos.Client(conf['bucket_name'], conf['ak'], service=conf['tos_psm'],
                                      cluster=conf['tos_cluster'], idc=conf['tos_idc'])

    def upload(self, key, value):
        duration = Duration()
        try:
            resp = self.client.put_object(key, StringIO(value))
            logger.info(f'{self.__class__.__name__}:upload:status={resp.status_code},'
                        f'request_id={resp.headers[bytedtos.consts.ReqIdHeader]},key={key},time={duration.minute()}')
        except bytedtos.TosException as e:
            logger.info(f'{self.__class__.__name__}:upload:status={e.code},request_id={e.request_id},message={e.msg}')

    def download(self, key):
        duration = Duration()
        try:
            resp = self.client.get_object(key)
            # 下载对象到内存中
            logger.info(f'{self.__class__.__name__}:download:status={resp.status_code},'
                        f'request_id={resp.headers[bytedtos.consts.ReqIdHeader]},key={key},time={duration.minute()}')
            # logger.info(f"data:{resp.data}")
            return resp.data
        except bytedtos.TosException as e:
            # 操作失败，捕获异常，可从返回信息中获取详细错误信息
            # request id 可定位具体问题，强烈建议日志中保存
            logger.info(f'{self.__class__.__name__}:download:status={e.code},request_id={e.request_id},message={e.msg}')
